@@ -2,9 +2,9 @@
 //!
 //! Handle authentication of HTTP calls.
 //!
-//! Authentication schemes can require specific workflows, such as making third-party calls to refresh a token or performing an initial request to get challenge information.
+//! Authentication protocols can require specific workflows, such as making third-party calls to refresh a token or performing an initial request to get challenge information.
 //!
-//! Using a fixed code structure, `authentic` can perform the necessary interactions for each authentication scheme. This allows schemes to be changed easily.
+//! Using a fixed code structure, `authentic` can perform the necessary interactions for each authentication protocol. This allows protocols to be changed easily.
 //!
 //! For example, the following code uses `reqwest` to access a site using HTTP Basic authentication. (See the [repository tests directory](https://github.com/jinxapi/authentic/tree/main/tests) for fully working examples).
 //!
@@ -47,15 +47,15 @@
 //! };
 //! ```
 //!
-//! The creation of the request takes place inside a loop. First, the authentication scheme is given an opportunity to perform any third-party calls using `step()`.
+//! The creation of the request takes place inside a loop. First, the authentication protocol is given an opportunity to perform any third-party calls using `step()`.
 //! HTTP Basic authentication does not use this, but it can be used, for example, to refresh an expired OAuth2 access token.
 //!
-//! The request is created using a standard `reqwest` RequestBuilder, using a new `with_authentication()` method to modify the request for the authentication scheme.
+//! The request is created using a standard `reqwest` RequestBuilder, using a new `with_authentication()` method to modify the request for the authentication protocol.
 //! For HTTP authentication, the first iteration makes no change to the request.
 //!
 //! The request is sent and a response is received.  For HTTP authentication, this returns a `401 Unauthorized` response.
 //!
-//! The `has_completed()` method checks if the response is ready to be returned or if the authentication scheme needs to retry.
+//! The `has_completed()` method checks if the response is ready to be returned or if the authentication protocol needs to retry.
 //! For HTTP authentication, this reads the returned `www-authenticate` challenge and establishes the correct credentials.
 //! As the request needs to be retried, `has_completed()` returns `false` and a second iteration begins.
 //!
@@ -108,7 +108,7 @@ pub trait AuthenticationProcess {
     }
 }
 
-pub trait AuthenticationScheme {
+pub trait AuthenticationProtocol {
     type Builder;
     type Request;
     type Response;
@@ -145,14 +145,14 @@ where
     #[must_use]
     fn with_authentication(
         self,
-        scheme: &dyn AuthenticationScheme<
+        protocol: &dyn AuthenticationProtocol<
             Builder = Self,
             Request = Request,
             Response = Response,
             Error = Error,
         >,
     ) -> Self {
-        scheme.configure(self)
+        protocol.configure(self)
     }
 }
 
