@@ -1,4 +1,4 @@
-//! Authentication schemes for use with blocking `reqwest`.
+//! Authentication protocols for use with blocking `reqwest`.
 //! Use the `reqwest_blocking` feature to enable these.
 
 use std::borrow::Cow;
@@ -8,11 +8,11 @@ use crate::credential::{
     AuthenticationCredentialToken, AuthenticationCredentialUsernamePassword, HttpRealmCredentials,
 };
 use crate::sensitive::SetSensitiveHeader;
-use crate::{AuthenticError, AuthenticationScheme, AuthenticationStep};
+use crate::{AuthenticError, AuthenticationProtocol, AuthenticationStep};
 
-/// No authentication scheme
+/// Protocol for no authentication
 ///
-/// Identical to not using `authentic` but allows minimal code changes when changing schemes.
+/// Identical to not using `authentic` but allows minimal code changes when changing protocols.
 pub struct NoAuthentication;
 
 impl NoAuthentication {
@@ -22,16 +22,16 @@ impl NoAuthentication {
     }
 }
 
-impl AuthenticationScheme for NoAuthentication {
+impl AuthenticationProtocol for NoAuthentication {
     type Builder = reqwest::blocking::RequestBuilder;
     type Request = reqwest::blocking::Request;
     type Response = reqwest::blocking::Response;
     type Error = reqwest::Error;
 }
 
-/// Authentication using a token in a specified haeader.
+/// Authentication using a token in a specified header.
 pub struct HeaderAuthentication<Credential> {
-    header_name: Cow<'static, [u8]>,
+    header_name: Cow<'static, str>,
     credential: Arc<Credential>,
 }
 
@@ -39,15 +39,15 @@ impl<Credential: 'static> HeaderAuthentication<Credential>
 where
     Credential: AuthenticationCredentialToken,
 {
-    pub fn new(header_name: Cow<'static, [u8]>, credential: &Arc<Credential>) -> Self {
+    pub fn new(header_name: impl Into<Cow<'static, str>>, credential: &Arc<Credential>) -> Self {
         Self {
-            header_name,
+            header_name: header_name.into(),
             credential: credential.clone(),
         }
     }
 }
 
-impl<Credential> AuthenticationScheme for HeaderAuthentication<Credential>
+impl<Credential> AuthenticationProtocol for HeaderAuthentication<Credential>
 where
     Credential: AuthenticationCredentialToken,
 {
@@ -61,6 +61,52 @@ where
     }
 }
 
+/// Authentication using a bearer token in the HTTP Authorization header.
+pub struct BearerAuthentication<Credential> {
+    auth_scheme: Cow<'static, str>,
+    credential: Arc<Credential>,
+}
+
+impl<Credential: 'static> BearerAuthentication<Credential>
+where
+    Credential: AuthenticationCredentialToken,
+{
+    pub fn new(credential: &Arc<Credential>) -> Self {
+        Self {
+            auth_scheme: "Bearer".into(),
+            credential: credential.clone(),
+        }
+    }
+
+    /// Change the default `Bearer` scheme to another string.
+    ///
+    /// Some systems use a bearer token, but use a scheme name other
+    /// than `Bearer`.
+    pub fn with_auth_scheme(mut self, auth_scheme: impl Into<Cow<'static, str>>) -> Self {
+        self.auth_scheme = auth_scheme.into();
+        self
+    }
+}
+
+impl<Credential> AuthenticationProtocol for BearerAuthentication<Credential>
+where
+    Credential: AuthenticationCredentialToken,
+{
+    type Builder = reqwest::blocking::RequestBuilder;
+    type Request = reqwest::blocking::Request;
+    type Response = reqwest::blocking::Response;
+    type Error = reqwest::Error;
+
+    fn configure(&self, builder: Self::Builder) -> Self::Builder {
+        let token = self.credential.token();
+        let mut value = Vec::with_capacity(self.auth_scheme.len() + 1 + token.len());
+        value.extend(self.auth_scheme.as_bytes());
+        value.push(b' ');
+        value.extend(token);
+        builder.set_sensitive_header(hyper::header::AUTHORIZATION, &value[..])
+    }
+}
+
 /// Authentication using HTTP Basic authentication on the initial call without waiting for a challenge.
 pub struct BasicAuthentication<Credential> {
     credential: Arc<Credential>,
@@ -77,7 +123,7 @@ where
     }
 }
 
-impl<Credential> AuthenticationScheme for BasicAuthentication<Credential>
+impl<Credential> AuthenticationProtocol for BasicAuthentication<Credential>
 where
     Credential: AuthenticationCredentialUsernamePassword,
 {
@@ -107,7 +153,7 @@ impl<Credential> HttpAuthentication<Credential> {
     }
 }
 
-impl<Credential> AuthenticationScheme for HttpAuthentication<Credential>
+impl<Credential> AuthenticationProtocol for HttpAuthentication<Credential>
 where
     Credential: AuthenticationCredentialUsernamePassword + 'static,
 {
@@ -165,7 +211,7 @@ where
                     Ok(true)
                 }
             }
-            Self::Basic(basic) => basic.has_completed(response)
+            Self::Basic(basic) => basic.has_completed(response),
         }
     }
 }
